@@ -1,10 +1,12 @@
 from typing import List, Optional, Union
 
+import msgspec.json
+
 from valo_api.endpoints_config import EndpointsConfig
 from valo_api.exceptions.valo_api_exception import ValoAPIException
 from valo_api.responses.error_response import ErrorResponse
 from valo_api.responses.leaderboard import LeaderboardPlayerV1, LeaderboardV2
-from valo_api.utils.fetch_endpoint import fetch_endpoint
+from valo_api.utils.fetch_endpoint import fetch_endpoint, response_type
 
 
 def get_leaderboard_v1(
@@ -119,17 +121,18 @@ def get_leaderboard(
         query_args=query_args,
         **kwargs,
     )
-    response_data = response.json()
 
     if response.ok is False:
-        headers = dict(response.headers)
-        raise ValoAPIException(
-            ErrorResponse.from_dict(headers=headers, **response_data)
-        )
+        error = msgspec.json.decode(response.content, type=ErrorResponse)
+        error.headers = dict(response.headers)
+        raise ValoAPIException(error)
 
     if version == "v1":
         if puuid is not None or name is not None or tag is not None:
-            response_data = response_data["data"]
-        return [LeaderboardPlayerV1.from_dict(**player) for player in response_data]
+            return msgspec.json.decode(
+                response.content, type=response_type(LeaderboardPlayerV1)
+            ).data
+        else:
+            return msgspec.json.decode(response.content, type=List[LeaderboardPlayerV1])
     else:
-        return LeaderboardV2.from_dict(**response_data)
+        return msgspec.json.decode(response.content, type=LeaderboardV2)
