@@ -1,10 +1,12 @@
 from typing import List
 
+import msgspec.json
+
 from valo_api.endpoints_config import EndpointsConfig
 from valo_api.exceptions.valo_api_exception import ValoAPIException
 from valo_api.responses.error_response import ErrorResponse
 from valo_api.responses.mmr_history import MMRHistoryPointV1
-from valo_api.utils.fetch_endpoint import fetch_endpoint
+from valo_api.utils.fetch_endpoint import fetch_endpoint, response_type
 
 
 def get_mmr_history_by_name_v1(
@@ -80,15 +82,15 @@ def get_mmr_history_by_name(
         version=version,
         **kwargs,
     )
-    response_data = response.json()
 
     if response.ok is False:
-        headers = dict(response.headers)
-        raise ValoAPIException(
-            ErrorResponse.from_dict(headers=headers, **response_data)
-        )
+        error = msgspec.json.decode(response.content, type=ErrorResponse)
+        error.headers = dict(response.headers)
+        raise ValoAPIException(error)
 
-    return [MMRHistoryPointV1.from_dict(**point) for point in response_data["data"]]
+    return msgspec.json.decode(
+        response.content, type=response_type(List[MMRHistoryPointV1])
+    ).data
 
 
 def get_mmr_history_by_puuid(
@@ -119,12 +121,12 @@ def get_mmr_history_by_puuid(
         version=version,
         **kwargs,
     )
-    response_data = response.json()
 
     if response.ok is False:
-        headers = dict(response.headers)
-        raise ValoAPIException(
-            ErrorResponse.from_dict(headers=headers, **response_data)
-        )
+        error = msgspec.json.decode(response.content, type=ErrorResponse)
+        error.headers = dict(response.headers)
+        raise ValoAPIException(error)
 
-    return [MMRHistoryPointV1.from_dict(**point) for point in response_data["data"]]
+    return msgspec.json.decode(
+        response.content, type=response_type(List[MMRHistoryPointV1])
+    ).data
