@@ -1,10 +1,12 @@
 from typing import List
 
+import msgspec.json
+
 from valo_api.endpoints_config import EndpointsConfig
 from valo_api.exceptions.valo_api_exception import ValoAPIException
 from valo_api.responses.error_response import ErrorResponse
 from valo_api.responses.website import WebsiteBannerV1
-from valo_api.utils.fetch_endpoint import fetch_endpoint
+from valo_api.utils.fetch_endpoint import fetch_endpoint, response_type
 
 
 def get_website_v1(countrycode: str, **kwargs) -> List[WebsiteBannerV1]:
@@ -45,12 +47,12 @@ def get_website(version: str, countrycode: str, **kwargs) -> List[WebsiteBannerV
         countrycode=countrycode,
         **kwargs,
     )
-    response_data = response.json()
 
     if response.ok is False:
-        headers = dict(response.headers)
-        raise ValoAPIException(
-            ErrorResponse.from_dict(headers=headers, **response_data)
-        )
+        error = msgspec.json.decode(response.content, type=ErrorResponse)
+        error.headers = dict(response.headers)
+        raise ValoAPIException(error)
 
-    return [WebsiteBannerV1.from_dict(**banner) for banner in response_data["data"]]
+    return msgspec.json.decode(
+        response.content, type=response_type(List[WebsiteBannerV1])
+    ).data
