@@ -1,12 +1,9 @@
 from typing import List
 
-from dataclasses import dataclass
-
-from valo_api.utils.init_options import InitOptions
+from msgspec import Struct
 
 
-@dataclass
-class CompetitiveMatchRaw(InitOptions):
+class CompetitiveMatchRaw(Struct):
     MatchID: str
     MapID: str
     SeasonID: str
@@ -21,11 +18,7 @@ class CompetitiveMatchRaw(InitOptions):
     AFKPenalty: int
 
 
-@dataclass
-class CompetitiveUpdatesRawV1(InitOptions):
+class CompetitiveUpdatesRawV1(Struct):
     Version: int
     Subject: str
     Matches: List[CompetitiveMatchRaw]
-
-    def __post_init__(self):
-        self.Matches = [CompetitiveMatchRaw.from_dict(**m) for m in self.Matches]
